library(testthat)
library(dostats)
test_check("dostats")
